import { Pool, PoolConfig } from 'pg';
import dotenv from 'dotenv';

dotenv.config();

// Configuration de base de la connexion
const poolConfig: PoolConfig = {
  user: process.env.DB_USER,
  host: process.env.DB_HOST || '192.168.0.104',
  database: process.env.DB_NAME || 'wimusic_db',
  password: process.env.DB_PASSWORD,
  port: parseInt(process.env.DB_PORT || '5432'),
  // Configuration du timeout et des tentatives de reconnexion
  connectionTimeoutMillis: 5000,
  idleTimeoutMillis: 30000,
  max: 20, // nombre maximum de clients dans le pool
};

// Si SSL est requis (recommandé pour la production)
if (process.env.DB_SSL === 'true') {
  poolConfig.ssl = {
    rejectUnauthorized: false // À modifier selon votre configuration SSL
  };
}

// Création du pool de connexions
const pool = new Pool(poolConfig);

// Gestion des événements de connexion
pool.on('connect', () => {
  console.log('📦 Connexion établie avec la base de données PostgreSQL');
  console.log(`📍 Hôte: ${poolConfig.host}`);
  console.log(`📚 Base de données: ${poolConfig.database}`);
});

// Gestion des erreurs
pool.on('error', (err) => {
  console.error('❌ Erreur de connexion à la base de données:', err);
  console.error('⚠️ Vérifiez vos paramètres de connexion et que le serveur est accessible');
});

// Fonction pour tester la connexion
export const testConnection = async (): Promise<boolean> => {
  try {
    const client = await pool.connect();
    console.log('✅ Test de connexion réussi');
    client.release();
    return true;
  } catch (error) {
    console.error('❌ Test de connexion échoué:', error);
    return false;
  }
};

export default pool; 