import { Request, Response, NextFunction } from 'express';
import { AppError } from './error.middleware';

/**
 * Middleware pour vérifier si l'utilisateur est authentifié
 */
export const isAuthenticated = (req: Request, res: Response, next: NextFunction) => {
  if (!req.session.userId) {
    throw new AppError(401, 'Non authentifié');
  }
  next();
};

/**
 * Middleware pour vérifier le type d'utilisateur
 */
export const checkUserType = (allowedTypes: string[]) => {
  return (req: Request, res: Response, next: NextFunction) => {
    if (!req.session.userType || !allowedTypes.includes(req.session.userType)) {
      throw new AppError(403, 'Accès non autorisé');
    }
    next();
  };
}; 