import { Request, Response, NextFunction } from 'express';
import helmet from 'helmet';
import rateLimit from 'express-rate-limit';

// Configuration du rate limiter
export const limiter = rateLimit({
  windowMs: 15 * 60 * 1000, // 15 minutes
  max: 100, // limite chaque IP à 100 requêtes par fenêtre
  message: 'Trop de requêtes depuis cette IP, veuillez réessayer plus tard'
});

// Configuration spécifique pour les routes d'authentification
export const authLimiter = rateLimit({
  windowMs: 60 * 60 * 1000, // 1 heure
  max: 5, // limite chaque IP à 5 tentatives par heure
  message: 'Trop de tentatives de connexion, veuillez réessayer plus tard'
});

// Middleware de sécurité
export const securityMiddleware = [
  helmet(), // Sécurité des en-têtes HTTP
  helmet.hidePoweredBy(), // Cache le header X-Powered-By
  helmet.noSniff(), // Empêche le MIME-type sniffing
  helmet.xssFilter(), // Protection XSS basique
];

// Middleware de validation du contenu JSON
export const validateJson = (
  err: Error,
  req: Request,
  res: Response,
  next: NextFunction
): Response | void => {
  if (err instanceof SyntaxError && 'body' in err) {
    return res.status(400).json({
      success: false,
      message: 'JSON invalide dans la requête'
    });
  }
  next();
}; 