import { body } from 'express-validator';
import { UserType } from '../types/user.types';

export const registerValidator = [
  // Email validation
  body('email')
    .trim()
    .isEmail()
    .withMessage('L\'adresse email n\'est pas valide')
    .normalizeEmail(),

  // Password validation
  body('password')
    .isLength({ min: 8 })
    .withMessage('Le mot de passe doit contenir au moins 8 caractères')
    .matches(/[A-Z]/)
    .withMessage('Le mot de passe doit contenir au moins une majuscule')
    .matches(/[a-z]/)
    .withMessage('Le mot de passe doit contenir au moins une minuscule')
    .matches(/[0-9]/)
    .withMessage('Le mot de passe doit contenir au moins un chiffre')
    .matches(/[!@#$%^&*]/)
    .withMessage('Le mot de passe doit contenir au moins un caractère spécial (!@#$%^&*)'),

  // Artist name validation
  body('artist_name')
    .trim()
    .notEmpty()
    .withMessage('Le nom d\'artiste est requis')
    .isLength({ min: 2, max: 100 })
    .withMessage('Le nom d\'artiste doit contenir entre 2 et 100 caractères'),

  // User type validation
  body('user_type')
    .optional()
    .isIn(['artist', 'venue_owner', 'partner', 'admin'] as UserType[])
    .withMessage('Le type d\'utilisateur n\'est pas valide'),

  // Bio validations
  body('bio_short')
    .optional()
    .trim()
    .isLength({ max: 200 })
    .withMessage('La bio courte ne doit pas dépasser 200 caractères'),

  body('bio_long')
    .optional()
    .trim()
    .isLength({ max: 2000 })
    .withMessage('La bio longue ne doit pas dépasser 2000 caractères')
]; 